Module camera

Module camera 

Module with camea utils Contrais implementations of trait camera Enable it with feature “camera”

Modules

orthographic
Use and create cameras easily Implementation for orthographic camera Enable it with feature “orthographic-camera”
prespective
Implementation for prespective camera Enable it with featurer “prespective-camera”

Structs

CameraBuffer
Simple buffer Implementation for camera matrix

Constants

OPENGL_TO_WGPU_MATRIX
Constant for conversion of opengl camera to wgpu camera

Traits

Camera
Abstraction of a camera