Module with resource managers Load resources of diferent types in memory Enable it with feature “resource-manager”
Structs
- Identifier
- Identifier for the resources
Traits
- Resource
Loader - Abstraction of a resource loader
Module with resource managers Load resources of diferent types in memory Enable it with feature “resource-manager”