pub struct Identifier {
pub root: String,
pub group: String,
pub id: String,
}Expand description
Identifier for the resources
Fields
root: StringRoot folder of the resource First folder to search Example ‘assets’ or ‘resources’
group: StringGroup of the resource Folder inside root, ‘textures’ or ‘models’
id: StringId of the resource File inside the group folder, or alone file inside the root folder
Implementations
Sourceimpl Identifier
impl Identifier
Sourcepub fn parse_from_str(id: &str) -> Self
pub fn parse_from_str(id: &str) -> Self
Convert a path into a Indentifier Example
let identifier = Indentifier::parse_from_str("assets/textures/tree.png");
assert_eq!(identifier.root, "assets");
assert_eq!(identifier.group, "textures");
assert_eq!(identifier.id, "tree.png");If the path doesnt has a group
let identifier = Identifier::parse_from_str("assets/cube.obj");
assert_eq!(identifier.root, "assets");
assert_eq!(identifier.group, "");
assert_eq!(identifier.id, "tree.png")pub fn root(&self) -> String
pub fn group(&self) -> String
pub fn id(&self) -> String
pub fn new(&self, root: &str, group: &str, id: &str) -> Self